# READ_FILE Package

This module is used to read data from .conf, .cfg and .yaml files. It reads and writes data in the json file and .env file
Install the module using pip install read_file and call the submodule read_yaml and read_conf according to requirements
